@@ -18,10 +18,10 @@
 
 
 
-static GdkPixbuf *button_load_pixbuf (const char  *file,
-				      int          size,
-				      char       **error);
-static GdkPixbuf * get_missing (int preffered_size);
+static GdkPixbuf * get_missing (GtkIconTheme *icon_theme,
+				int           preffered_size);
+static void button_widget_icon_theme_changed (ButtonWidget *button);
+static void button_widget_reload_pixbuf (ButtonWidget *button);
 
 enum {
 	PROP_0,
@@ -29,8 +29,7 @@ enum {
 	PROP_HAS_ARROW,
 	PROP_DND_HIGHLIGHT,
 	PROP_ORIENTATION,
-	PROP_ICON_NAME,
-	PROP_STOCK_ID
+	PROP_ICON_NAME
 };
 
 #define BUTTON_WIDGET_DISPLACEMENT 2
@@ -133,6 +132,14 @@ button_widget_realize(GtkWidget *widget)
 	gdk_window_set_user_data (button->event_window, widget);
 
 	widget->style = gtk_style_attach (widget->style, widget->window);
+
+	BUTTON_WIDGET (widget)->icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
+	g_signal_connect_object (BUTTON_WIDGET (widget)->icon_theme, "changed",
+				 G_CALLBACK (button_widget_icon_theme_changed),
+				 button,
+				 G_CONNECT_SWAPPED);
+
+	button_widget_reload_pixbuf (BUTTON_WIDGET (widget));
 }
 
 static void
@@ -170,56 +177,21 @@ button_widget_unset_pixbufs (ButtonWidget *button)
 	button->pixbuf_hc = NULL;
 }
 
-static GdkPixbuf *
-button_widget_load_and_scale_stock_icon (ButtonWidget *button)
-{
-	GdkPixbuf *new;
-	GdkPixbuf *retval;
-	double     scale;
-	int        width;
-	int        height;
-
-	new = gtk_widget_render_icon (GTK_WIDGET (button),
-				      button->stock_id,
-				      (GtkIconSize) -1,
-				      NULL);
-
-	width  = gdk_pixbuf_get_width  (new);
-	height = gdk_pixbuf_get_height (new);
-
-	if (button->orientation & PANEL_HORIZONTAL_MASK)
-		scale = (double) button->size / height;
-	else
-		scale = (double) button->size / width;
-
-	width  *= scale;
-	height *= scale;
-
-	retval = gdk_pixbuf_scale_simple (new, width, height,
-					  GDK_INTERP_BILINEAR);
-
-	g_object_unref (new);
-
-	return retval;
-}
-
 static void
 button_widget_reload_pixbuf (ButtonWidget *button)
 {
 	button_widget_unset_pixbufs (button);
 
-	if (button->size <= 1)
+	if (button->size <= 1 || button->icon_theme == NULL)
 		return;
 
-	if (!button->filename && !button->stock_id)
-		return;
-
-	if (button->filename != NULL) {
+	if (button->filename != NULL && button->filename [0] != '\0') {
 		char *error = NULL;
 
-		button->pixbuf = button_load_pixbuf (button->filename,
-						     button->size,
-						     &error);
+		button->pixbuf = panel_load_icon (button->icon_theme,
+						  button->filename,
+						  button->size,
+						  &error);
 		if (error) {
 			panel_error_dialog (gdk_screen_get_default (),
 					    "cannot_load_pixbuf", TRUE,
@@ -231,11 +203,9 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 		}
 	}
 
-	if (button->pixbuf == NULL && button->stock_id != NULL)
-		button->pixbuf = button_widget_load_and_scale_stock_icon (button);
-
 	if (button->pixbuf == NULL)
-		button->pixbuf = get_missing (button->size);
+		button->pixbuf = get_missing (button->icon_theme,
+					      button->size);
 
 	if (button->pixbuf == NULL)
 		return;
@@ -252,13 +222,6 @@ button_widget_icon_theme_changed (ButtonWidget *button)
 		button_widget_reload_pixbuf (button);
 }
 
-static void
-button_widget_gtk_theme_changed (ButtonWidget *button)
-{
-	if (button->stock_id != NULL)
-		button_widget_reload_pixbuf (button);
-}
-
 static void
 button_widget_finalize (GObject *object)
 {
@@ -269,9 +232,6 @@ button_widget_finalize (GObject *object)
 	g_free (button->filename);
 	button->filename = NULL;
 
-	g_free (button->stock_id);
-	button->stock_id = NULL;
-	
 	parent_class->finalize (object);
 }
 
@@ -303,9 +263,6 @@ button_widget_get_property (GObject    *object,
 	case PROP_ICON_NAME:
 		g_value_set_string (value, button->filename);
 		break;
-	case PROP_STOCK_ID:
-		g_value_set_string (value, button->stock_id);
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
@@ -340,96 +297,26 @@ button_widget_set_property (GObject      *object,
 	case PROP_ICON_NAME:
 		button_widget_set_icon_name (button, g_value_get_string (value));
 		break;
-	case PROP_STOCK_ID:
-		button_widget_set_stock_id (button, g_value_get_string (value));
-		break;
 	default:
 		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 		break;
 	}
 }
 
-static char *default_pixmap = NULL;
-
 static GdkPixbuf *
-get_missing (int preffered_size)
+get_missing (GtkIconTheme *icon_theme,
+	     int           preffered_size)
 {
 	GdkPixbuf *retval = NULL;
 
-	if (default_pixmap == NULL)
-		default_pixmap = gnome_desktop_item_find_icon (panel_icon_theme, "gnome-unknown.png",
-							       preffered_size, 0);
-	if (default_pixmap != NULL)
-		retval = gdk_pixbuf_new_from_file_at_size (default_pixmap,
-							   preffered_size,
-							   preffered_size,
-							   NULL);
+	retval = gtk_icon_theme_load_icon (icon_theme, "gnome-unknown",
+					   preffered_size, 0, NULL);
 	if (retval == NULL)
 		retval = missing_pixbuf (preffered_size);
 
 	return retval;
 }
 
-static GdkPixbuf *
-load_pixbuf (const char  *file,
-	     int          preffered_size,
-	     char       **str_error)
-{
-	GError    *error = NULL;
-	GdkPixbuf *retval = NULL;
-	char      *full;
-
-	if (g_path_is_absolute (file))
-		full = g_strdup (file);
-	else
-		full = gnome_desktop_item_find_icon (panel_icon_theme, file, preffered_size, 0);
-
-	if (full) {
-		retval = gdk_pixbuf_new_from_file_at_size (full,
-							   preffered_size,
-							   preffered_size,
-							   &error);
-		if (!retval) {
-			if (str_error)
-				*str_error = g_strdup (error ? error->message : _("none"));
-			g_error_free (error);
-		}
-		g_free (full);
-	} else if (str_error)
-		*str_error = g_strdup (_("file not found"));
-
-	return retval;
-
-
-}
-
-static GdkPixbuf *
-button_load_pixbuf (const char  *file,
-		    int          preffered_size,
-		    char       **error)
-{
-	GdkPixbuf *retval = NULL;
-
-	if (string_empty (file))
-		return NULL;
-
-	retval = load_pixbuf (file, preffered_size, NULL);
-	if (!retval) {
-		char *tmp;
-
-		if (error && *error) {
-			g_free (*error);
-			*error = NULL;
-		}
-
-		tmp = g_path_get_basename (file);
-		retval = load_pixbuf (tmp, preffered_size, error);
-		g_free (tmp);
-	}
-
-	return retval;
-}
-
 static GtkArrowType
 calc_arrow (PanelOrientation  orientation,
 	    int               button_width,
@@ -699,24 +586,20 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 static void
 button_widget_instance_init (ButtonWidget *button)
 {
-	button->pixbuf    = NULL;
-	button->pixbuf_hc = NULL;
+	button->icon_theme = NULL;
+	button->pixbuf     = NULL;
+	button->pixbuf_hc  = NULL;
+
+	button->filename   = NULL;
 	
-	button->arrow       = 0;
 	button->orientation = PANEL_ORIENTATION_TOP;
-	
-	button->ignore_leave  = FALSE;
-	button->dnd_highlight = FALSE;
 
 	button->size = 0;
-
-	g_signal_connect_object (panel_icon_theme, "changed",
-				 G_CALLBACK (button_widget_icon_theme_changed),
-				 button,
-				 G_CONNECT_SWAPPED);
-
-	g_signal_connect (button, "style-set", 
-			  G_CALLBACK (button_widget_gtk_theme_changed), button);
+	
+	button->activatable   = FALSE;
+	button->ignore_leave  = FALSE;
+	button->arrow         = FALSE;
+	button->dnd_highlight = FALSE;
 }
 
 static void
@@ -788,15 +671,6 @@ button_widget_class_init (ButtonWidgetClass *klass)
 					     "The desired icon for the ButtonWidget",
 					     NULL,
 					     G_PARAM_READWRITE));
-
-	g_object_class_install_property (
-			gobject_class,
-			PROP_STOCK_ID,
-			g_param_spec_string ("stock-id",
-					     "Stock Icon ID",
-					     "The desired stock icon for the ButtonWidget",
-					     NULL,
-					     G_PARAM_READWRITE));
 }
 
 GType
@@ -841,23 +715,6 @@ button_widget_new (const char       *filename,
 	return retval;
 }
 
-GtkWidget *
-button_widget_new_from_stock (const char       *stock_id,
-			      gboolean          arrow,
-			      PanelOrientation  orientation)
-{
-	GtkWidget *retval;
-
-	retval = g_object_new (
-			BUTTON_TYPE_WIDGET,
-			"has-arrow", arrow,
-			"orientation", orientation,
-			"stock-id", stock_id,
-			NULL);
-	
-	return retval;
-}
-
 void
 button_widget_set_activatable (ButtonWidget *button,
 			       gboolean      activatable)
@@ -910,32 +767,6 @@ button_widget_get_icon_name (ButtonWidget *button)
 	return button->filename;
 }
 
-void
-button_widget_set_stock_id (ButtonWidget *button,
-			    const char   *stock_id)
-{
-	g_return_if_fail (BUTTON_IS_WIDGET (button));
-	
-	if (button->stock_id && stock_id && !strcmp (button->stock_id, stock_id))
-		return;
-
-	if (button->stock_id)
-		g_free (button->stock_id);
-	button->stock_id = g_strdup (stock_id);
-
-	button_widget_reload_pixbuf (button);
-
-	g_object_notify (G_OBJECT (button), "stock-id");
-}
-
-const char *
-button_widget_get_stock_id (ButtonWidget *button)
-{
-	g_return_val_if_fail (BUTTON_IS_WIDGET (button), NULL);
-	
-	return button->stock_id;
-}
-
 void
 button_widget_set_orientation (ButtonWidget     *button,
 			       PanelOrientation  orientation)
